Certified Products : New CC Portal

Login

- NEWS
- ICCC
- PROTECTION PROFILES
- COLLABORATIVE PPS
- CERTIFIED PRODUCTS
- TECHNICAL COMMUNITIES
- PUBLICATIONS
- ABOUT THE CC
- HOME

# Certified Products

Statistics Download CSV Archived Certified Products

The Common Criteria Recognition Arrangement covers certificates with claims of compliance against Common Criteria assurance components of either:

a collaborative Protection Profile (cPP), developed and maintained in accordance with CCRA Annex K, with assurance activities selected from Evaluation Assurance Levels up to and including level 4 and ALC_FLR, developed through an International Technical Community endorsed by the Management Committee; or
Evaluation Assurance Levels 1 through 2 and ALC_FLR.

Where a CC certificate claims compliance to Evaluation Assurance Level 3 or higher, but does not claim compliance to a collaborative Protection Profile, then for purposes of mutual recognition under the CCRA, the CC certificate should be treated as equivalent to Evaluation Assurance Level 2.

The CCDB has approved a resolution to limit the validity of mutually recognized CC certificates over time. Certificates will remain on the CPL for five years. Effective 1 June 2019, certificates with an expired validity period (that is, 5 years or more from the date of certificate issuance) will be moved to an Archive list on the CCRA portal, unless the validity period has been extended using the appropriate procedures.

#### expand/collapse all categories

Product | Vendor | Product Certificate | Date Certificate Issued | Certificate Validity Expiration Date | Compliance | Scheme
--- | --- | --- | --- | --- | --- | ---
This list was generated on Wednesday, November 11, 2020, at 10:47 AM
Access Control Devices and Systems – 27 Certified Products
NetIQ Identity Manager 4.7 Certification Report Security Target | NetIQ Corporation | CCRA Certificate | 2020-06-15 | 2025-06-15 | EAL3+ ALC_FLR.2 | SE
Magic SSO V4.0 Certification Report Security Target Korean National Protection Profile for Single Sign On V1.0 | Dreamsecurity Co., Ltd. |  | 2019-11-15 | 2024-11-15 | PP Compliant | KR

Product | Vendor | Product Certificate | Date Certificate Issued | Certificate Validity Expiration Date | Compliance | Scheme
--- | --- | --- | --- | --- | --- | ---
This list was generated on Tuesday, October 4, 2022, at 9:32 AM
Data Protection – 61 Certified Products
Fortinet FortiGate w/ FortiOS v5.6.7 Certification Report Security Target collaborative Protection Profile for Stateful Traffic Filter Firewalls v2.0 + Errata 20180314 Maintenance Report(s) 2019-08-26 – Fortinet FortiGate w/ FortiOS v5.6.7 Build 6022 Maintenance Report Maintenance ST | Fortinet, Inc. | CCRA Certificate | 2019-05-22 | 2024-05-24 | PP Compliant | CA